@@ -19,7 +19,6 @@
 PurposePlugin::PurposePlugin(QObject *parent)
     : AbstractBrowserPlugin(QStringLiteral("purpose"), 1, parent)
 {
-
 }
 
 PurposePlugin::~PurposePlugin()
@@ -36,11 +35,10 @@ bool PurposePlugin::onUnload()
 QJsonObject PurposePlugin::handleData(int serial, const QString &event, const QJsonObject &data)
 {
     if (event == QLatin1String("share")) {
-
         if (m_pendingReplySerial != -1 || (m_menu && m_menu->isVisible())) {
             return {
                 {QStringLiteral("success"), false},
-                {QStringLiteral("errorCode"), QStringLiteral("BUSY")}
+                {QStringLiteral("errorCode"), QStringLiteral("BUSY")},
             };
         }
 
@@ -55,7 +53,7 @@ QJsonObject PurposePlugin::handleData(int serial, const QString &event, const QJ
 
         if (!m_menu) {
             m_menu.reset(new Purpose::Menu());
-            m_menu->model()->setPluginType(QStringLiteral("Export"));
+            m_menu->model()->setPluginType(QStringLiteral("ShareUrl"));
 
             connect(m_menu.data(), &QMenu::aboutToShow, this, [this] {
                 m_menu->setProperty("actionInvoked", false);
@@ -67,13 +65,17 @@ QJsonObject PurposePlugin::handleData(int serial, const QString &event, const QJ
                 // got canceled, when hovering an action and then hitting Escape to close the menu.
                 // Hence delaying this and checking if an action got invoked :(
 
-                QMetaObject::invokeMethod(this, [this] {
-                    if (!m_menu->property("actionInvoked").toBool()) {
-                        sendPendingReply(false, {
-                            {QStringLiteral("errorCode"), QStringLiteral("CANCELED")}
-                        });
-                    }
-                }, Qt::QueuedConnection);
+                QMetaObject::invokeMethod(
+                    this,
+                    [this] {
+                        if (!m_menu->property("actionInvoked").toBool()) {
+                            sendPendingReply(false,
+                                             {
+                                                 {QStringLiteral("errorCode"), QStringLiteral("CANCELED")},
+                                             });
+                        }
+                    },
+                    Qt::QueuedConnection);
             });
 
             connect(m_menu.data(), &QMenu::triggered, this, [this] {
@@ -84,10 +86,11 @@ QJsonObject PurposePlugin::handleData(int serial, const QString &event, const QJ
                 if (errorCode) {
                     debug() << "Error:" << errorCode << errorMessage;
 
-                    sendPendingReply(false, {
-                        {QStringLiteral("errorCode"), errorCode},
-                        {QStringLiteral("errorMessage"), errorMessage}
-                    });
+                    sendPendingReply(false,
+                                     {
+                                         {QStringLiteral("errorCode"), errorCode},
+                                         {QStringLiteral("errorMessage"), errorMessage},
+                                     });
                     return;
                 }
 
@@ -98,9 +101,7 @@ QJsonObject PurposePlugin::handleData(int serial, const QString &event, const QJ
                 }
 
                 debug() << "Finished:" << output;
-                sendPendingReply(true, {
-                    {QStringLiteral("response"), output}
-                });
+                sendPendingReply(true, {{QStringLiteral("response"), output}});
             });
         }
 
@@ -143,7 +144,7 @@ QJsonObject PurposePlugin::handleData(int serial, const QString &event, const QJ
         m_pendingReplySerial = -1;
         return {
             {QStringLiteral("success"), false},
-            {QStringLiteral("errorCode"), QStringLiteral("INVALID_ARGUMENT")}
+            {QStringLiteral("errorCode"), QStringLiteral("INVALID_ARGUMENT")},
         };
     }
 
